==> DynamicNestedField-0.0.11.tar.gz: DynamicNestedField-0.0.11/src/DynamicNestedField/DjangoModelsFields.py <==
fields = {
    "AutoField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "BLANK_CHOICE_DASH": ['exact'],
    "BigAutoField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "BigIntegerField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "BinaryField": ['exact'],
    "BooleanField": ['exact'],
    "CharField": ['exact', 'contains', 'icontains', 'endswith', 'iendswith', 'regex', 'iregex', 'startswith', 'istartswith'],
    "CommaSeparatedIntegerField": ['exact'],
    "DateField": ['exact', 'date', 'day', 'month', 'quarter', 'week', 'week_day', 'year'],
    "DateTimeField": ['exact', 'date', 'day', 'month', 'quarter', 'week', 'week_day', 'year', 'hour', 'minute', 'second', 'time'],
    "DecimalField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "DurationField": ['exact'],
    "EmailField": ['exact', 'contains', 'icontains', 'endswith', 'iendswith', 'regex', 'iregex', 'startswith', 'istartswith'],
    "Empty": ['exact'],
    "Field": ['exact'],
    "FilePathField": ['exact', 'contains', 'icontains', 'endswith', 'iendswith', 'regex', 'iregex', 'startswith', 'istartswith'],
    "FloatField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "GenericIPAddressField": ['exact', 'contains', 'icontains', 'endswith', 'iendswith', 'regex', 'iregex', 'startswith', 'istartswith'],
    "IPAddressField": ['exact', 'contains', 'icontains', 'endswith', 'iendswith', 'regex', 'iregex', 'startswith', 'istartswith'],
    "IntegerField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "NOT_PROVIDED": ['exact'],
    "NullBooleanField": ['exact'],
    "PositiveBigIntegerField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "PositiveIntegerField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "PositiveSmallIntegerField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "SlugField": ['exact', 'contains', 'icontains', 'endswith', 'iendswith', 'regex', 'iregex', 'startswith', 'istartswith'],
    "SmallAutoField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "SmallIntegerField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "TextField": ['exact', 'contains', 'icontains', 'endswith', 'iendswith', 'regex', 'iregex', 'startswith', 'istartswith'],
    "TimeField": ['exact', 'hour', 'minute', 'second', 'time'],
    "URLField": ['exact', 'contains', 'icontains', 'endswith', 'iendswith', 'regex', 'iregex', 'startswith', 'istartswith'],
    "UUIDField": ['exact', 'contains', 'icontains', 'endswith', 'iendswith', 'regex', 'iregex', 'startswith', 'istartswith'],
}

==> DynamicNestedField-0.0.13.tar.gz: DynamicNestedField-0.0.13/src/DynamicNestedField/DjangoModelsFields.py <==
fields = {
    "AutoField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "BLANK_CHOICE_DASH": ['exact'],
    "BigAutoField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "BigIntegerField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "BinaryField": ['exact'],
    "BooleanField": ['exact'],
    "CharField": ['exact', 'contains', 'icontains', 'endswith', 'iendswith', 'regex', 'iregex', 'startswith', 'istartswith'],
    "CommaSeparatedIntegerField": ['exact'],
    "DateField": ['exact', 'day', 'month', 'quarter', 'week', 'week_day', 'year'],
    "DateTimeField": ['exact', 'date', 'day', 'month', 'quarter', 'week', 'week_day', 'year', 'hour', 'minute', 'second', 'time'],
    "DecimalField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "DurationField": ['exact'],
    "EmailField": ['exact', 'contains', 'icontains', 'endswith', 'iendswith', 'regex', 'iregex', 'startswith', 'istartswith'],
    "Empty": ['exact'],
    "Field": ['exact'],
    "FilePathField": ['exact', 'contains', 'icontains', 'endswith', 'iendswith', 'regex', 'iregex', 'startswith', 'istartswith'],
    "FloatField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "GenericIPAddressField": ['exact', 'contains', 'icontains', 'endswith', 'iendswith', 'regex', 'iregex', 'startswith', 'istartswith'],
    "IPAddressField": ['exact', 'contains', 'icontains', 'endswith', 'iendswith', 'regex', 'iregex', 'startswith', 'istartswith'],
    "IntegerField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "NOT_PROVIDED": ['exact'],
    "NullBooleanField": ['exact'],
    "PositiveBigIntegerField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "PositiveIntegerField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "PositiveSmallIntegerField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "SlugField": ['exact', 'contains', 'icontains', 'endswith', 'iendswith', 'regex', 'iregex', 'startswith', 'istartswith'],
    "SmallAutoField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "SmallIntegerField": ['exact', 'lt', 'lte', 'gt', 'gte'],
    "TextField": ['exact', 'contains', 'icontains', 'endswith', 'iendswith', 'regex', 'iregex', 'startswith', 'istartswith'],
    "TimeField": ['exact', 'hour', 'minute', 'second', 'time'],
    "URLField": ['exact', 'contains', 'icontains', 'endswith', 'iendswith', 'regex', 'iregex', 'startswith', 'istartswith'],
    "UUIDField": ['exact', 'contains', 'icontains', 'endswith', 'iendswith', 'regex', 'iregex', 'startswith', 'istartswith'],
}
